#include <pluginlib/class_list_macros.h>
#include <ros/ros.h>

#include "mavLink/mavLink.h"

#include "car/stmDataMsg.h"
#include "car/ccDataMsg.h"
#include "car/laneDataMsg.h"
#include "car/rcEnabledMsg.h"

PLUGINLIB_EXPORT_CLASS(car::MavLink, nodelet::Nodelet);

namespace car
{
	MavLink::MavLink(ros::NodeHandle &nh, std::string &name) :
    nh_(nh), 
    name_(name)
    {}
  
	MavLink::MavLink() {}
  
	MavLink::~MavLink() {}
  
	void MavLink::onInit()
	{
		NODELET_INFO("MavLink::onInit -- START");
	  stmData = nh_.advertise<stmDataMsg>("stmData", 1);
	  ccData = nh_.subscribe("ccData", 1, &MavLink::ccDataCallback, this);
	  laneData = nh_.subscribe("laneData", 1, &MavLink::laneDataCallback, this);
	  rcEnabled = nh_.subscribe("rcEnabled", 1, &MavLink::rcEnabledCallback, this);
		NODELET_INFO("MavLink::onInit -- END");
	}

  void MavLink::ccDataCallback(const ccDataMsg::ConstPtr& inMsg)
  {
    std::cout << "MavLink recived new cc data (" << inMsg->speed << ").\n";
  }

  void MavLink::laneDataCallback(const laneDataMsg::ConstPtr& inMsg)
  {
    std::cout << "MavLink recived new lane data ( ).\n";
  }
  
  void MavLink::rcEnabledCallback(const rcEnabledMsg::ConstPtr& inMsg)
  {
    std::cout << "MavLink recived new rc status (" << inMsg->enabled << ").\n";
  }
  
  
}
